Title: [138007] trunk/Tools
Revision
138007
Author
[email protected]
Date
2012-12-18 03:58:46 -0800 (Tue, 18 Dec 2012)

Log Message

[EFL][WK2] Gardening of TestWebKitAPI tests
https://bugs.webkit.org/show_bug.cgi?id=105268

Reviewed by Kenneth Rohde Christiansen.

Some tests were marked as failing but are passing and the newly added
LayoutUnit should have it's own binary because it conflicts with the
fixture used by KURL and is failing on the bots because of that.

* TestWebKitAPI/CMakeLists.txt:
* TestWebKitAPI/PlatformEfl.cmake:

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (138006 => 138007)


--- trunk/Tools/ChangeLog	2012-12-18 11:57:23 UTC (rev 138006)
+++ trunk/Tools/ChangeLog	2012-12-18 11:58:46 UTC (rev 138007)
@@ -1,3 +1,17 @@
+2012-12-18  Thiago Marcos P. Santos  <[email protected]>
+
+        [EFL][WK2] Gardening of TestWebKitAPI tests
+        https://bugs.webkit.org/show_bug.cgi?id=105268
+
+        Reviewed by Kenneth Rohde Christiansen.
+
+        Some tests were marked as failing but are passing and the newly added
+        LayoutUnit should have it's own binary because it conflicts with the
+        fixture used by KURL and is failing on the bots because of that.
+
+        * TestWebKitAPI/CMakeLists.txt:
+        * TestWebKitAPI/PlatformEfl.cmake:
+
 2012-12-18  Jochen Eisinger  <[email protected]>
 
         [chromium] move webintent related methods to TestRunner library

Modified: trunk/Tools/TestWebKitAPI/CMakeLists.txt (138006 => 138007)


--- trunk/Tools/TestWebKitAPI/CMakeLists.txt	2012-12-18 11:57:23 UTC (rev 138006)
+++ trunk/Tools/TestWebKitAPI/CMakeLists.txt	2012-12-18 11:58:46 UTC (rev 138007)
@@ -100,18 +100,13 @@
     ${WebCore_LIBRARY_NAME}
 )
 
-add_executable(test_webcore
-    ${test_main_SOURCES}
-    ${TESTWEBKITAPI_DIR}/TestsController.cpp
-    ${TESTWEBKITAPI_DIR}/Tests/WebCore/KURL.cpp
-    ${TESTWEBKITAPI_DIR}/Tests/WebCore/LayoutUnit.cpp
-)
+foreach (testName ${test_webcore_BINARIES})
+    add_executable(test_webcore_${testName} ${test_main_SOURCES} ${TESTWEBKITAPI_DIR}/TestsController.cpp ${TESTWEBKITAPI_DIR}/Tests/WebCore/${testName}.cpp)
+    add_test(test_webcore_${testName} ${CMAKE_RUNTIME_OUTPUT_DIRECTORY}/test_webcore_${testName})
+    set_tests_properties(test_webcore_${testName} PROPERTIES TIMEOUT 60)
+    target_link_libraries(test_webcore_${testName} ${test_webcore_LIBRARIES})
+endforeach ()
 
-target_link_libraries(test_webcore ${test_webcore_LIBRARIES})
-add_dependencies(test_webcore ${ForwardingHeadersForTestWebKitAPI_NAME} ${ForwardingNetworkHeadersForTestWebKitAPI_NAME})
-add_test(test_webcore ${CMAKE_RUNTIME_OUTPUT_DIRECTORY}/test_webcore)
-set_tests_properties(test_webcore PROPERTIES TIMEOUT 60)
-
 add_library(TestWebKitAPIBase
     ${test_main_SOURCES}
     ${webkit2_api_harness_SOURCES}

Modified: trunk/Tools/TestWebKitAPI/PlatformEfl.cmake (138006 => 138007)


--- trunk/Tools/TestWebKitAPI/PlatformEfl.cmake	2012-12-18 11:57:23 UTC (rev 138006)
+++ trunk/Tools/TestWebKitAPI/PlatformEfl.cmake	2012-12-18 11:58:46 UTC (rev 138007)
@@ -36,16 +36,22 @@
 )
 
 # The list below works like a test expectation. Tests in the
 # test_webkit2_api_BINARIES list are added to the test runner and
 # tried on the bots on every build. Tests in test_webkit2_api_fail_BINARIES
 # are compiled and suffixed with fail and skipped from the test runner.
 #
 # Make sure that the tests are passing on both Debug and
 # Release builds before adding it to test_webkit2_api_BINARIES.
 
+set(test_webcore_BINARIES
+    LayoutUnit
+    KURL
+)
+
 set(test_webkit2_api_BINARIES
     AboutBlankLoad
     CookieManager
+    DOMWindowExtensionBasic
     DOMWindowExtensionNoCache
     DocumentStartUserScriptAlertCrash
     EvaluateJavaScript
@@ -63,11 +69,13 @@
     MouseMoveAfterCrash
     NewFirstVisuallyNonEmptyLayout
     NewFirstVisuallyNonEmptyLayoutFails
+    NewFirstVisuallyNonEmptyLayoutForImages
     PageLoadBasic
     PageLoadDidChangeLocationWithinPageForFrame
     ParentFrame
     PreventEmptyUserAgent
     PrivateBrowsingPushStateNoHistoryCallback
+    ShouldGoToBackForwardListItem
     WKConnection
     WKPreferences
     WKString
@@ -78,12 +86,9 @@
 
 set(test_webkit2_api_fail_BINARIES
     CanHandleRequest
-    DOMWindowExtensionBasic
     DownloadDecideDestinationCrash
-    NewFirstVisuallyNonEmptyLayoutForImages
     NewFirstVisuallyNonEmptyLayoutFrames
     RestoreSessionStateContainingFormData
-    ShouldGoToBackForwardListItem
     WKPageGetScaleFactorNotZero
 )
 
@@ -36,16 +36,22 @@
 
 # The list below works like a test expectation. Tests in the
-# test_webkit2_api_BINARIES list are added to the test runner and
-# tried on the bots on every build. Tests in test_webkit2_api_fail_BINARIES
+# test_{webkit2_api|webcore}_BINARIES list are added to the test runner and
+# tried on the bots on every build. Tests in test_{webkit2_api|webcore}_BINARIES
 # are compiled and suffixed with fail and skipped from the test runner.
 #
@@ -36,16 +36,22 @@
 #
 # Make sure that the tests are passing on both Debug and
-# Release builds before adding it to test_webkit2_api_BINARIES.
+# Release builds before adding it to test_{webkit2_api|webcore}_BINARIES.
 
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to